==> qtjambi-pdfwidgets-6.4.0-sources.jar: io/qt/pdf/widgets/QtJambi_LibraryUtilities.java <==
package io.qt.pdf.widgets;

final class QtJambi_LibraryUtilities {

    final static int qtMajorVersion = 6;

    final static int qtMinorVersion = 4;

    final static int qtJambiPatch = 0;

    static{
        try {
            io.qt.QtUtilities.initializePackage("io.qt.internal");
            io.qt.QtUtilities.loadQtLibrary("DBus", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "macos", "linux");
            io.qt.QtUtilities.loadQtLibrary("Network", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "linux");
            io.qt.QtUtilities.loadQtLibrary("OpenGL", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "linux");
            io.qt.QtUtilities.loadQtLibrary("Qml", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly);
            io.qt.QtUtilities.loadQtLibrary("QmlModels", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly);
            io.qt.QtUtilities.loadQtLibrary("Quick", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly);
            io.qt.QtUtilities.loadQtLibrary("Svg", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly);
            io.qt.QtUtilities.loadQtLibrary("VirtualKeyboard", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly);
            io.qt.QtUtilities.loadQtLibrary("WaylandClient", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "linux");
            io.qt.QtUtilities.loadQtLibrary("WaylandEglClientHwIntegration", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "linux");
            io.qt.QtUtilities.loadQtLibrary("WlShellIntegration", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "linux");
            io.qt.QtUtilities.loadUtilityLibrary("d3dcompiler_47", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "windows");
            io.qt.QtUtilities.loadUtilityLibrary("libEGL", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "windows");
            io.qt.QtUtilities.loadUtilityLibrary("libGLESv2", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "windows");
            io.qt.QtUtilities.loadUtilityLibrary("opengl32sw", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "windows");
            io.qt.QtUtilities.loadQtLibrary("Gui", io.qt.QtUtilities.LibraryRequirementMode.Mandatory);
            io.qt.QtUtilities.loadQtLibrary("Widgets", io.qt.QtUtilities.LibraryRequirementMode.Mandatory);
            io.qt.QtUtilities.loadQtLibrary("Network", io.qt.QtUtilities.LibraryRequirementMode.Mandatory);
            io.qt.QtUtilities.loadQtLibrary("Pdf", io.qt.QtUtilities.LibraryRequirementMode.Mandatory);
            io.qt.QtUtilities.loadQtLibrary("PdfWidgets", io.qt.QtUtilities.LibraryRequirementMode.Mandatory);
            io.qt.QtUtilities.loadQtJambiLibrary("PdfWidgets");
        } catch(Error t) {
            throw t;
        } catch(Throwable t) {
            throw new ExceptionInInitializerError(t);
        }
    }
    static final io.qt.InternalAccess internal = internalAccess();

    private static native io.qt.InternalAccess internalAccess();

    static void initialize() { };

    private QtJambi_LibraryUtilities() throws java.lang.InstantiationError { throw new java.lang.InstantiationError("Cannot instantiate QtJambi_LibraryUtilities."); }
}

==> qtjambi-pdfwidgets-6.4.2-sources.jar: io/qt/pdf/widgets/QtJambi_LibraryUtilities.java <==
package io.qt.pdf.widgets;

final class QtJambi_LibraryUtilities {

    final static int qtMajorVersion = 6;

    final static int qtMinorVersion = 4;

    final static int qtJambiPatch = 2;

    final static io.qt.InternalAccess internal;

    static{
        try {
            io.qt.QtUtilities.initializePackage("io.qt.internal");
            io.qt.QtUtilities.loadQtLibrary("DBus", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "macos", "linux");
            io.qt.QtUtilities.loadQtLibrary("Network", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "linux");
            io.qt.QtUtilities.loadQtLibrary("OpenGL", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "linux");
            io.qt.QtUtilities.loadQtLibrary("Qml", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly);
            io.qt.QtUtilities.loadQtLibrary("QmlModels", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly);
            io.qt.QtUtilities.loadQtLibrary("Quick", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly);
            io.qt.QtUtilities.loadQtLibrary("Svg", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly);
            io.qt.QtUtilities.loadQtLibrary("VirtualKeyboard", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly);
            io.qt.QtUtilities.loadQtLibrary("WaylandClient", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "linux");
            io.qt.QtUtilities.loadQtLibrary("WaylandEglClientHwIntegration", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "linux");
            io.qt.QtUtilities.loadQtLibrary("WlShellIntegration", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "linux");
            io.qt.QtUtilities.loadUtilityLibrary("d3dcompiler_47", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "windows");
            io.qt.QtUtilities.loadUtilityLibrary("libEGL", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "windows");
            io.qt.QtUtilities.loadUtilityLibrary("libGLESv2", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "windows");
            io.qt.QtUtilities.loadUtilityLibrary("opengl32sw", io.qt.QtUtilities.LibraryRequirementMode.ProvideOnly, "windows");
            io.qt.QtUtilities.loadQtLibrary("Gui", io.qt.QtUtilities.LibraryRequirementMode.Mandatory);
            io.qt.QtUtilities.loadQtLibrary("Widgets", io.qt.QtUtilities.LibraryRequirementMode.Mandatory);
            io.qt.QtUtilities.loadQtLibrary("Network", io.qt.QtUtilities.LibraryRequirementMode.Mandatory);
            io.qt.QtUtilities.loadQtLibrary("Pdf", io.qt.QtUtilities.LibraryRequirementMode.Mandatory);
            io.qt.QtUtilities.loadQtLibrary("PdfWidgets", io.qt.QtUtilities.LibraryRequirementMode.Mandatory);
            io.qt.QtUtilities.loadQtJambiLibrary("PdfWidgets");
        } catch(Error t) {
            throw t;
        } catch(Throwable t) {
            throw new ExceptionInInitializerError(t);
        }
        internal = internalAccess();
    }
    private static native io.qt.InternalAccess internalAccess();

    static void initialize() { };

    private QtJambi_LibraryUtilities() throws java.lang.InstantiationError { throw new java.lang.InstantiationError("Cannot instantiate QtJambi_LibraryUtilities."); }
}
